package com.xxl.job.admin.controller.interceptor;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.xxl.job.admin.controller.annotation.PermissionLimit;
import com.xxl.job.admin.core.model.XxlJobGroup;
import com.xxl.job.admin.core.model.XxlJobUser;
import com.xxl.job.admin.core.util.I18nUtil;
import com.xxl.job.admin.service.impl.LoginService;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.stereotype.Component;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.AsyncHandlerInterceptor;

@Component
public class PermissionInterceptor implements AsyncHandlerInterceptor {
  @Resource
  private LoginService loginService;
  
  public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
    if (!(handler instanceof HandlerMethod))
      return true; 
    boolean needLogin = true;
    boolean needAdminuser = false;
    HandlerMethod method = (HandlerMethod)handler;
    PermissionLimit permission = (PermissionLimit)method.getMethodAnnotation(PermissionLimit.class);
    if (permission != null) {
      needLogin = permission.limit();
      needAdminuser = permission.adminuser();
    } 
    if (needLogin) {
      XxlJobUser loginUser = this.loginService.ifLogin(request, response);
      if (loginUser == null) {
        response.setStatus(302);
        response.setHeader("location", request.getContextPath() + "/toLogin");
        return false;
      } 
      if (needAdminuser && loginUser.getRole() != 1)
        throw new RuntimeException(I18nUtil.getString("system_permission_limit")); 
      request.setAttribute("XXL_JOB_LOGIN_IDENTITY", loginUser);
    } 
    return true;
  }
  
  public static XxlJobUser getLoginUser(HttpServletRequest request) {
    XxlJobUser loginUser = (XxlJobUser)request.getAttribute("XXL_JOB_LOGIN_IDENTITY");
    return loginUser;
  }
  
  public static void validJobGroupPermission(HttpServletRequest request, int jobGroup) {
    XxlJobUser loginUser = getLoginUser(request);
    if (!loginUser.validPermission(jobGroup))
      throw new RuntimeException(I18nUtil.getString("system_permission_limit") + "[username=" + loginUser.getUsername() + "]"); 
  }
  
  public static List<XxlJobGroup> filterJobGroupByRole(HttpServletRequest request, List<XxlJobGroup> jobGroupList_all) {
    List<XxlJobGroup> jobGroupList = new ArrayList<>();
    if (jobGroupList_all != null && jobGroupList_all.size() > 0) {
      XxlJobUser loginUser = getLoginUser(request);
      if (loginUser.getRole() == 1) {
        jobGroupList = jobGroupList_all;
      } else {
        List<String> groupIdStrs = new ArrayList<>();
        if (loginUser.getPermission() != null && loginUser.getPermission().trim().length() > 0)
          groupIdStrs = Arrays.asList(loginUser.getPermission().trim().split(",")); 
        for (XxlJobGroup groupItem : jobGroupList_all) {
          if (groupIdStrs.contains(String.valueOf(groupItem.getId())))
            jobGroupList.add(groupItem); 
        } 
      } 
    } 
    return jobGroupList;
  }
}
